package java.awt.image;

import sun.awt.image.SunWritableRaster;
import sun.java2d.StateTrackable;
import sun.java2d.StateTrackableDelegate;

public abstract class DataBuffer
{
    public static final int TYPE_BYTE = 0;
    public static final int TYPE_USHORT = 1;
    public static final int TYPE_SHORT = 2;
    public static final int TYPE_INT = 3;
    public static final int TYPE_FLOAT = 4;
    public static final int TYPE_DOUBLE = 5;
    public static final int TYPE_UNDEFINED = 32;
    protected int dataType;
    protected int banks;
    protected int offset;
    protected int size;
    protected int[] offsets;
    StateTrackableDelegate theTrackable;
    private static final int[] dataTypeSize;
    
    public static int getDataTypeSize(int i) {
        if (i < 0 || i > 5) {
            throw new IllegalArgumentException("Unknown data type " + i);
        }
        return DataBuffer.dataTypeSize[i];
    }
    
    protected DataBuffer(int n, int n2) {
        this(StateTrackable.State.UNTRACKABLE, n, n2);
    }
    
    DataBuffer(StateTrackable.State state, int dataType, int size) {
        this.theTrackable = StateTrackableDelegate.createInstance(state);
        this.dataType = dataType;
        this.banks = 1;
        this.size = size;
        this.offset = 0;
        this.offsets = new int[1];
    }
    
    protected DataBuffer(int n, int n2, int n3) {
        this(StateTrackable.State.UNTRACKABLE, n, n2, n3);
    }
    
    DataBuffer(StateTrackable.State state, int dataType, int size, int banks) {
        this.theTrackable = StateTrackableDelegate.createInstance(state);
        this.dataType = dataType;
        this.banks = banks;
        this.size = size;
        this.offset = 0;
        this.offsets = new int[this.banks];
    }
    
    protected DataBuffer(int n, int n2, int n3, int n4) {
        this(StateTrackable.State.UNTRACKABLE, n, n2, n3, n4);
    }
    
    DataBuffer(StateTrackable.State state, int dataType, int size, int banks, int offset) {
        this.theTrackable = StateTrackableDelegate.createInstance(state);
        this.dataType = dataType;
        this.banks = banks;
        this.size = size;
        this.offset = offset;
        this.offsets = new int[banks];
        for (int i = 0; i < banks; ++i) {
            this.offsets[i] = offset;
        }
    }
    
    protected DataBuffer(int n, int n2, int n3, int[] array) {
        this(StateTrackable.State.UNTRACKABLE, n, n2, n3, array);
    }
    
    DataBuffer(StateTrackable.State state, int dataType, int size, int banks, int[] array) {
        if (banks != array.length) {
            throw new ArrayIndexOutOfBoundsException("Number of banks does not match number of bank offsets");
        }
        this.theTrackable = StateTrackableDelegate.createInstance(state);
        this.dataType = dataType;
        this.banks = banks;
        this.size = size;
        this.offset = array[0];
        this.offsets = (int[])(int[])array.clone();
        return;
    }
    
    public int getDataType() {
        return this.dataType;
    }
    
    public int getSize() {
        return this.size;
    }
    
    public int getOffset() {
        return this.offset;
    }
    
    public int[] getOffsets() {
        return (int[])(int[])this.offsets.clone();
    }
    
    public int getNumBanks() {
        return this.banks;
    }
    
    public int getElem(int n) {
        return this.getElem(0, n);
    }
    
    public abstract int getElem(int p0, int p1);
    
    public void setElem(int n, int n2) {
        this.setElem(0, n, n2);
    }
    
    public abstract void setElem(int p0, int p1, int p2);
    
    public float getElemFloat(int n) {
        return (float)this.getElem(n);
    }
    
    public float getElemFloat(int n, int n2) {
        return (float)this.getElem(n, n2);
    }
    
    public void setElemFloat(int n, float n2) {
        this.setElem(n, (int)n2);
    }
    
    public void setElemFloat(int n, int n2, float n3) {
        this.setElem(n, n2, (int)n3);
    }
    
    public double getElemDouble(int n) {
        return (double)this.getElem(n);
    }
    
    public double getElemDouble(int n, int n2) {
        return (double)this.getElem(n, n2);
    }
    
    public void setElemDouble(int n, double n2) {
        this.setElem(n, (int)n2);
    }
    
    public void setElemDouble(int n, int n2, double n3) {
        this.setElem(n, n2, (int)n3);
    }
    
    static int[] toIntArray(Object o) {
        if ((o instanceof int[])) {
            return (int[])(int[])o;
        }
        if (o == null) {
            return null;
        }
        if ((o instanceof short[])) {
            short[] array3 = (short[])(short[])o;
            int[] array4 = new int[array3.length];
            for (int j = 0; j < array3.length; ++j) {
                array4[j] = (array3[j] & 0xFFFF);
            }
            return array4;
        }
        if ((o instanceof byte[])) {
            byte[] array = (byte[])(byte[])o;
            int[] array2 = new int[array.length];
            for (int i = 0; i < array.length; ++i) {
                array2[i] = (0xFF & array[i]);
            }
            return array2;
        }
        return null;
    }
    
    static {
        dataTypeSize = new int[] { 8, 16, 16, 32, 32, 64 };
        SunWritableRaster.setDataStealer(new SunWritableRaster.DataStealer() {
            @Override
            public byte[] getData(DataBufferByte dataBufferByte, int n) {
                return dataBufferByte.bankdata[n];
            }
            
            @Override
            public short[] getData(DataBufferUShort dataBufferUShort, int n) {
                return dataBufferUShort.bankdata[n];
            }
            
            @Override
            public int[] getData(DataBufferInt dataBufferInt, int n) {
                return dataBufferInt.bankdata[n];
            }
            
            @Override
            public StateTrackableDelegate getTrackable(DataBuffer dataBuffer) {
                return dataBuffer.theTrackable;
            }
            
            @Override
            public void setTrackable(DataBuffer dataBuffer, StateTrackableDelegate theTrackable) {
                dataBuffer.theTrackable = theTrackable;
            }
        });
    }
}
